@@ -1,4 +1,5 @@
 import requests
+import grequests
 from requests.exceptions import ConnectionError
 from bs4 import BeautifulSoup as beautifulsoup
 import re
@@ -177,7 +178,7 @@ class Connection(object):
 
     @property
     def last_response_soup(self):
-        return beautifulsoup(self.last_response.text)
+        return self.pack(self.last_response)
 
     def get(self, url, proto='http'):
         """
@@ -193,6 +194,36 @@ class Connection(object):
                                               allow_redirects=True)
         return self.last_response_soup
 
+    def pack(self, response, async=False):
+        soup = beautifulsoup(response.text)
+        if async:
+            response.close()
+        return soup
+
+    def getmultipleasync(self, urls, proto='http'):
+        reqs = (grequests.get(proto + self.base_uri + u,
+                              headers=self.headers,
+                              session=self.session,
+                              cookies=self.cookies,
+                              allow_redirects=True)
+                for u in urls)
+        return grequests.map(reqs)
+
+    def getmultiplesync(self, urls, proto='http'):
+        result = []
+        for u in urls:
+            self.get(u, proto)
+            result.append(self.last_response)
+        return result
+
+    def getmultiple(self, urls, proto='http', async=False):
+        result = []
+        if len(urls) > 0:
+            fx = self.getmultipleasync if async else self.getmultiplesync
+            result = fx(urls, proto)
+            result = filter(lambda x: x is not None, result)
+        return list(map(lambda r, a=async: self.pack(r, a), result))
+
     def post(self, url, data, proto='http', form_name=None):
         """
         Load an url using the POST method.
