@@ -2,8 +2,6 @@ from noaaclass import core
 import re
 from datetime import datetime, timedelta
 
-MAX_HOURS = '48'
-
 select = lambda i, n, data: [d for d in data if d['id'] == i or d['name'] == n]
 changed = lambda x, data: x != select(x['id'], x['name'], data)[0]
 is_new = lambda e, old_data: (e['id'] is '+'
@@ -39,15 +37,16 @@ class api(core.api):
         self.translate(multiple, 'channel', int, 'chan_%s' % self.name, str)
         self.translate(single, 'format', direct, 'format_%s' % self.name, str)
 
-    def subscribe_get_append_orders(self, noaa, d):
-        noaa.get('order_list?order=%s&type=SUBS&displayDetails=Y&hours=%s'
-                 '&status_page=1&group_size=25' % (d['id'], MAX_HOURS))
+    def subscribe_get_append_orders(self, noaa, d, append_files, hours, async):
+        noaa.get('order_list?order=%s&type=SUBS&displayDetails=Y&hours=%i'
+                 '&status_page=1&group_size=25' % (d['id'], hours))
         item = lambda i: {'id': str(i.text)}
         is_item = lambda i: i.text.isdigit()
-        d['orders'] = self.obtain_items(noaa, item, is_item)
-        self.parse_orders(noaa, d['orders'])
+        d['orders'] = self.obtain_items(noaa.last_response_soup, item, is_item)
+        self.parse_orders(noaa, d['orders'], append_files, hours, async)
 
-    def subscribe_get(self, append_orders=False):
+    def subscribe_get(self, append_orders=False, append_files=False, hours=1,
+                      async=False):
         noaa = self.conn
         page = noaa.get('subscriptions')
         data = page.select('.class_table td a')
@@ -64,7 +63,8 @@ class api(core.api):
             tmp = join(tmp, forms['sub_frm'])
             d.update(self.post_to_local(tmp))
             if append_orders:
-                self.subscribe_get_append_orders(noaa, d)
+                self.subscribe_get_append_orders(noaa, d, append_files,
+                                                 hours, async)
         return data
 
     def subscribe_new(self, e):
@@ -96,8 +96,8 @@ class api(core.api):
     def subscribe_remove(self, e):
         self.conn.get('sub_delete?actionbox=%s' % e['id'])
 
-    def subscribe_classify(self, data):
-        old_data = self.subscribe_get(append_orders=False)
+    def subscribe_classify(self, data, async):
+        old_data = self.subscribe_get(append_orders=False, async=async)
         incomplete = [d for d in data if need_id(d, old_data)]
         for d in incomplete:
             d['id'] = select(d['id'], d['name'], old_data)[0]['id']
@@ -106,32 +106,37 @@ class api(core.api):
         edit = [e for e in data if e not in new and changed(e, old_data)]
         return remove, new, edit
 
-    def subscribe_set(self, data, append_orders=False):
-        remove, new, edit = self.subscribe_classify(data)
+    def subscribe_set(self, data, append_orders=False, async=False):
+        remove, new, edit = self.subscribe_classify(data, async)
         list(map(self.subscribe_new, new))
         list(map(self.subscribe_edit, edit))
         list(map(self.subscribe_remove, remove))
 
     def parse_area(self, head, order):
         coords = ['south', 'north', 'west', 'east']
+        cast = lambda n, v: self.keys['get'][self.keys['set'][n][0]][1](v)
         for index in range(len(coords)):
-            order[coords[index]] = float(head[8+index].text) / 100
+            name = coords[index]
+            value = head[8+index].text
+            order[name] = cast(name, value) / 100
 
-    def parse_files(self, noaa, order):
-        head = noaa.last_response_soup.select('.class_table td')
-        order['format'] = head[1].text
-        self.parse_area(head, order)
-        files = map(file_data,
-                    noaa.last_response_soup.select('.zebra tr')[1:])
-        files = map(lambda x: (x[0], x[1]), filter(lambda x: x[2], files))
-        order['files'].extend(files)
-
-    def obtain_items(self, noaa, item_functor, check_functor):
-        anchors = noaa.last_response_soup.select('.zebra td a')
+    def obtain_items(self, last_response_soup, item_functor, check_functor):
+        anchors = last_response_soup.select('.zebra td a')
         return map(item_functor, filter(check_functor, anchors))
 
-    def parse_order(self, noaa, order):
-        table = noaa.last_response_soup.select('.class_table td')
+    def parse_head(self, noaa, order, last_response_soup):
+        url = last_response_soup.select('.zebra td a')[0].attrs['href']
+        last_response_soup = noaa.get(url)
+        head = last_response_soup.select('.class_table td')
+        self.parse_area(head, order)
+        other = {
+            'format': head[1].text,
+            'channel': range(int(head[12].text), int(head[13].text)+1),
+        }
+        order.update(other)
+
+    def parse_order(self, noaa, order, last_response_soup):
+        table = last_response_soup.select('.class_table td')
         order['delivered'] = (table[4].text
                               in ['Order Delivered', 'Order Ready'])
         order['datetime'] = datetime.strptime(table[3].text,
@@ -139,41 +144,42 @@ class api(core.api):
         order['files'] = {'http': [], 'ftp': []}
         day_before_yesterday = datetime.utcnow() - timedelta(days=2)
         order['old'] = order['datetime'] < day_before_yesterday
-        item = lambda i: i['href'].split("'")[1]
-        is_http = lambda i: 'www' in i.text
-        is_ftp = lambda i: 'ftp' in i.text
-        for i in self.obtain_items(noaa, item, is_http):
-            order['files']['http'].append(i)
-        for i in self.obtain_items(noaa, item, is_ftp):
-            order['files']['ftp'].append(i)
+        self.parse_head(noaa, order, last_response_soup)
+        if self.append_files:
+            item = lambda i: i['href'].split("'")[1]
+            is_http = lambda i: 'www' in i.text
+            is_ftp = lambda i: 'ftp' in i.text
+            order['files']['http'].extend(
+                self.obtain_items(last_response_soup, item, is_http))
+            order['files']['ftp'].extend(
+                self.obtain_items(last_response_soup, item, is_ftp))
 
-    def parse_orders(self, noaa, orders):
-        for order in orders:
-            noaa.get('order_details?order=%s&hours=%s&status_page=1'
-                     '&group_size=25' % (order['id'], MAX_HOURS))
-            self.parse_order(noaa, order)
+    def parse_orders(self, noaa, orders, append_files, hours, async):
+        self.append_files = append_files
+        urls = [('order_details?order=%s&hours=%i&status_page=1'
+                 '&group_size=1000' % (order['id'], hours))
+                for order in orders]
+        responses = noaa.getmultiple(urls, async=async)
+        list(map(lambda a, noaa=noaa: self.parse_order(noaa, a[0], a[1]),
+                 zip(orders, responses)))
 
-    def request_get(self):
+    def request_get(self, append_files=False, hours=1, async=False):
         noaa = self.conn
-        page = noaa.get('order_list')
-        forms = noaa.translator.get_forms(noaa.last_response_soup)
-        tmp = forms['o_form']
-        tmp['hours'] = [MAX_HOURS]
-        tmp['type'] = ['USER']
-        tmp['submit'] = ['Submit']
-        page = noaa.post('order_list', tmp, form_name='o_form')
+        page = noaa.get('order_list?order=&status=&type=USER'
+                        '&displayDetails=N&hours=%i&status_page=1'
+                        '&large_status=&group_size=1000&orderby=0' %
+                        (hours))
         data = page.select('.zebra td a')
         data = [{'id': d.text}
                 for d in data if d.text.isdigit()]
-        self.parse_orders(noaa, data)
-        key = lambda x: x['start']
+        self.parse_orders(noaa, data, append_files, hours, async)
+        key = lambda x: x['start'] if 'start' in x else ''
         data.sort(key=key)
         return data
 
     def request_new(self, e):
-        """
         noaa = self.conn
-        noaa.get('search?sub_id=0&datatype_family=%ssubmit.x=23&submit.y=7' %
+        noaa.get('search?sub_id=0&datatype_family=%s&submit.x=23&submit.y=7' %
                  self.name_upper)
         data = self.local_to_post(e)
         data['start_date'] = e['start'].strftime('%Y-%m-%d')
@@ -182,68 +188,28 @@ class api(core.api):
         data['end_time'] = e['end'].strftime('%H:%M:%S')
         data['data_start'] = '1993-09-01'
         data['data_end'] = datetime.utcnow().strftime('%Y-%m-%d')
-        data['dsname_pattern'] = '^GOES\d\d\.(19|20)\d\d\.[0123]\d\d(.{0,15})$'
-        import ipdb; ipdb.set_trace()
-        print noaa.last_response
+        data['dsname_pattern'] = "^GOES\d\d\.(19|20)\d\d\.[0123]\d\d(.{0,15})$"
+        data['between_through'] = 'T'
         noaa.post('psearch%s' % self.name_upper, data=data,
                   form_name='search_frm')
-        print len(noaa.last_response_soup.select('form[name=rform] input'))
-        # forms = noaa.translator.get_forms(noaa.last_response_soup)
-        # print '~~', dict(map(scrap_form, filter(has_name, forms)))
-        # tmp = forms['gform']
-        # tmp['update_action'] = ['SelectAll']
-        # print forms['gform'], '\n', forms['rform']
-        # noaa.post('results%s' % name, data=tmp, form_name='gform')
-        # print forms.keys()
-        # noaa.get('http://www.nsof.class.noaa.gov/saa/products/shopping_cart')
-        # forms = noaa.translator.get_forms(noaa.last_response_soup)
-        # tmp = forms['shop']
-        # data = self.post_to_local()
-        """
-        """
-        self.conn.post('sub_deliver', data, form_name='sub_frm')
-        channel_mask = list('000000' + 'X' * 24)
-        data = self.local_to_post(e)
-        for i in e['channel']:
-            channel_mask[i-1] = '1'
-            data['channels_%s' % name] = ''.join(channel_mask),
-        self.conn.post('sub_save', data, form_name='sub_frm')
-        """
-        """dsname_pattern:^GOES\d\d\.(19|20)\d\d\.[0123]\d\d(.{0,15})$
-        data_start:1993-09-01
-        data_end:2014-08-26
-        start_date:2014-07-23
-        start_time:00:00:00
-        end_date:2014-07-23
-        end_time:23:59:59
-        between_through:T
-        max_sum_hits:100
-        lrg_max_sum_hits:4000
-        brk_srch_hrs_qs:0
-        bulk_order:N"""
-        """psearchGVAR_IMG
-        update_action:SelectAll"""
-        """resultsGVAR_IMG"""
-        """shopping_cart
-        email:noaaclass.test@gmail.com
-        cocoon-action:PlaceOrder
-        format_top_GVAR_IMG:NetCDF
-        channels_top_GVAR_IMG:1
-        channels_top_GVAR_IMG:2
-        channels_top_GVAR_IMG:3
-        channels_top_GVAR_IMG:4
-        channels_top_GVAR_IMG:56
-        channels_368965203_GVAR_IMG:1
-        channels_368965203_GVAR_IMG:2
-        channels_368965203_GVAR_IMG:3
-        channels_368965203_GVAR_IMG:4
-        channels_368965203_GVAR_IMG:6
-        """
-        """survey
-        purpose:education
-        postSurvey:Submit
-        """
-        pass
+        forms = noaa.translator.get_forms(noaa.last_response_soup)
+        tmp = forms['rform']
+        tmp['update_action'] = ['SelectAll']
+        noaa.post('results%s' % self.name, data=tmp, form_name='rform')
+        forms = noaa.translator.get_forms(noaa.last_response_soup)
+        noaa.get('shopping_cart')
+        forms = noaa.translator.get_forms(noaa.last_response_soup)
+        tmp = forms['shop']
+        trans = (lambda k, v, e: [e['format']]
+                 if 'format' in k else (e['channel'] if 'channel' in k else v))
+        tmp = {k: trans(k, v, e) for k, v in tmp.items()}
+        tmp['cocoon-action'] = ['PlaceOrder']
+        self.conn.post('shop', data=tmp, form_name='shop')
+        forms = noaa.translator.get_forms(noaa.last_response_soup)
+        tmp = forms['FORM1']
+        tmp['purpose'] = ['education']
+        tmp['postSurvey'] = ['Submit']
+        self.conn.post('survey', data=tmp, form_name='FORM1')
 
     def request_set(self, data):
         new = [e for e in data if e['id'] is '+']
