@@ -1,6 +1,7 @@
 import unittest
 from noaaclass import noaaclass
 from datetime import datetime
+import time
 
 
 class TestGvarimg(unittest.TestCase):
@@ -69,8 +70,8 @@ class TestGvarimg(unittest.TestCase):
              'satellite': ['G13'],
              'channel': [1],
              'format': 'NetCDF',
-             'start': datetime(2014, 9, 3, 0, 0, 0),
-             'end': datetime(2014, 9, 4, 23, 59, 59)
+             'start': datetime(2014, 9, 16, 10, 0, 0),
+             'end': datetime(2014, 9, 16, 17, 59, 59)
              },
             {'id': '+',
              'north': -26.73,
@@ -82,8 +83,8 @@ class TestGvarimg(unittest.TestCase):
              'satellite': ['G13'],
              'channel': [2],
              'format': 'NetCDF',
-             'start': datetime(2014, 9, 2, 0, 0, 0),
-             'end': datetime(2014, 9, 3, 23, 59, 59)
+             'start': datetime(2014, 9, 2, 10, 0, 0),
+             'end': datetime(2014, 9, 3, 17, 59, 59)
              },
         ]
 
@@ -105,7 +106,8 @@ class TestGvarimg(unittest.TestCase):
     def test_subscribe_get(self):
         self.gvar_img = self.noaa.subscribe.gvar_img
         self.gvar_img.set(self.sub_data)
-        for subscription in self.gvar_img.get(append_orders=True):
+        for subscription in self.gvar_img.get(append_orders=True,
+                                              append_files=True):
             for key in ['id', 'enabled', 'name', 'coverage', 'schedule',
                         'south', 'north', 'west', 'east', 'satellite',
                         'format', 'orders']:
@@ -135,7 +137,7 @@ class TestGvarimg(unittest.TestCase):
 
     def test_subscribe_set_remove_element(self):
         self.gvar_img = self.noaa.subscribe.gvar_img
-        copy = self.gvar_img.set(self.sub_data)
+        copy = self.gvar_img.set(self.sub_data, async=True)
         self.assertEquals(self.gvar_img.get(), copy)
         criteria = lambda x: 'sample1' not in x['name']
         copy = filter(criteria, copy)
@@ -149,19 +151,29 @@ class TestGvarimg(unittest.TestCase):
                         'south', 'north', 'west', 'east']:
                 self.assertIn(key, order.keys())
 
-    def test_request_set_new(self):
-        """self.gvar_img = self.noaa.request.gvar_img
-        copy = self.gvar_img.set(self.req_data)
-        self.assertEquals(len(copy), 2)
-        sort = sorted
-        [self.assertEquals(sort(copy[i].keys()), sort(self.req_data[i].keys()))
-         for i in range(len(self.req_data))]
-        [self.assertEquals(copy[i][k], v)
-         for i in range(len(self.req_data))
-         for k, v in self.req_data[i].items()
-         if k is not 'id']
-        """
-        pass
+    def assertEqualsRequests(self, obtained, original):
+        asymetric = lambda x: x not in ['coverage', 'end', 'start',
+                                        'satellite', 'schedule', 'id']
+        for k in filter(asymetric, original.keys()):
+            self.assertTrue(k in obtained.keys())
+            if isinstance(original[k], float):
+                self.assertEqual(int(obtained[k]), int(original[k]))
+            elif isinstance(original[k], datetime):
+                self.assertEqual(obtained[k].toordinal(),
+                                 original[k].toordinal())
+            else:
+                self.assertEquals(obtained[k], original[k])
+
+    def no_test_request_set_new(self):
+        time.sleep(40)
+        self.gvar_img = self.noaa.request.gvar_img
+        data = self.gvar_img.get(async=True)
+        data.extend(self.req_data)
+        copy = self.gvar_img.set(data, async=True)
+        self.assertEquals(len(copy), len(data))
+        [self.assertEqualsRequests(copy[i], data[i])
+         for i in range(len(data))]
+        time.sleep(40)
 
 if __name__ == '__main__':
     unittest.main()
